
####DADA2####

library(dada2)


#Browse vignette informations on Dada2
browseVignettes("dada2")


#Set path to demultiplexed taxa
path <- "~/Desktop/Test_Epfu/demultiplexing_fasta/"
list.files(path)


# Forward and reverse fastq filenames have format: SAMPLENAME_R1_001.fastq and SAMPLENAME_R2_001.fastq
fnFs <- sort(list.files(path, pattern="EPFU1", full.names = TRUE))
fnRs <- sort(list.files(path, pattern="EPFU2", full.names = TRUE))


# Extract sample names, assuming filenames have format: SAMPLENAME_XXX.fastq
sample.names <- sapply(strsplit(basename(fnFs), "_"), `[`, 2)


####Inspect read quality profiles####
plotQualityProfile(fnFs)
plotQualityProfile(fnRs)
#1. Draw amplicon diagram
#2. Choose the trunclen


#####Filter and trim####
# Place filtered files in filtered/subdirectory
filtFs <- file.path(path, "filtered", paste0(sample.names, "_F_filt.fastq.gz"))
filtRs <- file.path(path, "filtered", paste0(sample.names, "_R_filt.fastq.gz"))

#Filter
out <- filterAndTrim(fnFs, filtFs, fnRs, filtRs, truncLen=c(240,200),
                     maxN=0, maxEE=c(2,2), truncQ=2, rm.phix=TRUE,
                     compress=TRUE, trimLeft=c(8, 8), multithread=TRUE) # On Windows set multithread=FALSE
head(out)


####Sanity check of filtered file####
plotQualityProfile(filtFs, aggregate=TRUE)
plotQualityProfile(filtRs, aggregate=TRUE)


####Dereplication####
derepFs <- derepFastq(filtFs, verbose=TRUE)
derepRs <- derepFastq(filtRs, verbose=TRUE)
#Name the derep-class objects by the sample names
names(derepFs) <- sample.names
names(derepRs) <- sample.names


####Learn the Error Rates####
#SAVE THIS: the longest step!
errF <- learnErrors(derepFs, multithread=TRUE)
errR <- learnErrors(derepRs, multithread=TRUE)

#Visualize the estimated error rates:
plotErrors(errF, nominalQ=TRUE)
plotErrors(errR, nominalQ=TRUE)


####Sample Inference####
dadaFs <- dada(derepFs, err=errF, multithread=TRUE)
dadaRs <- dada(derepRs, err=errR, multithread=TRUE)
print(dadaFs)
print(dadaRs)


####Merge paired reads####
#Make sequence table
mergers <- mergePairs(dadaFs, derepFs, dadaRs, derepRs, verbose=TRUE)
#Inspect the merger data.frame from the first sample
head(mergers[[1]])
mergers=readRDS("Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/mergers")

#Construct sequence table
seqtab <- makeSequenceTable(mergers)
dim(seqtab)

#Inspect distribution of sequence lengths
table(nchar(getSequences(seqtab)))
sumseq=sum(seqtab)

#Remove chimeras
seqtab.nochim <- removeBimeraDenovo(seqtab, method="consensus", multithread=TRUE, verbose=TRUE)
dim(seqtab.nochim)
#Proportion and number of non-chimera sequences
sum(seqtab.nochim)/sum(seqtab)
table(nchar(getSequences(seqtab.nochim)))

#Remove non-target-length sequences from sequence table
seqtabnochim2<-seqtab.nochim[,nchar(colnames(seqtab.nochim))%in%232:287]
table(nchar(getSequences(seqtabnochim2)))


####Track reads through the pipeline####
getN <- function(x) sum(getUniques(x))
track <- cbind(out, sapply(dadaFs, getN), sapply(dadaRs, getN), sapply(mergers, getN), rowSums(seqtabnochim2))
colnames(track) <- c("input", "filtered", "denoisedF", "denoisedR", "merged", "nonchim")
rownames(track) <- sample.names
head(track)


####Assign taxonomy####
taxa <- assignTaxonomy(seqtabnochim2, "~/Desktop/Test_Epfu/silva_nr_v132_train_set.fa", multithread=TRUE)

#Removing sequence rownames for display only
taxa.print <- taxa 
rownames(taxa.print) <- NULL
head(taxa.print)
taxa.print
saveRDS(taxa.print, "Desktop/Test_Epfu/taxa.print")
View(seqtabnochim2)

#Remove 7 last character from rowname (fastq)
seqtabnochim4=seqtabnochim2
rownames(seqtabnochim4)=str_sub(rownames(seqtabnochim4), end=-7)
rownames(seqtabnochim4)


#Change colnames in seqtab nochim for genera
seqtabnochim3=seqtabnochim2
colnames(seqtabnochim3) = taxa.print[,6]
dim(seqtabnochim3)

#Create new object
seqtabnochim5=seqtabnochim4
#Change ASV name for Genus name
colnames(seqtabnochim5)=taxa[,6]

####Filter Halomonas, Shewanella, mitochondria and chloroplast####
#Find column number which are halomonas
halo.find=which(colnames(seqtabnochim5)=="Halomonas")
#Remove Halomonas from ASV table and taxonomy
seqtabnochim5=seqtabnochim5[,-halo.find]
taxa5=taxa[-halo.find,]

#Repeat previous step with Shewanella
Shewa.find=which(colnames(seqtabnochim5)=="Shewanella")
seqtabnochim5=seqtabnochim5[,-Shewa.find]
taxa5=taxa5[-Shewa.find,]

#Put back ASV in colnames
colnames(seqtabnochim5)=rownames(taxa5)



####Create Phylogenetics tree ####
library("DECIPHER")
library("phangorn")
library("ips")
#Extract sequences from DADA2 output
sequences<-getSequences(seqtabnochim5)
names(sequences)<-sequences
#Run Sequence Alignment (MSA) using DECIPHER
alignment <- AlignSeqs(DNAStringSet(sequences), anchor=NA)
alignment <- read.dna("alignment.fasta",format="fasta",as.matrix=TRUE)

#In FastTree in terminal
#Compile fastTree
#gcc -Wall -O3 -finline-functions -funroll-loops -o FastTree -lm FastTree.c
#Executable 
#chmod +x FastTree
#Run tree phylogeny
#./FastTree -nt /Users/virginielemieux-labonte/Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/alignment.fasta > Tree_EPFU1  e


#########################################
#########################################
############## Phyloseq #################
#########################################
#########################################
library("vegan")
library("phyloseq")
library("ggplot2")

#Import FastTree tree
tree = read_tree_greengenes("~/Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/Tree_EPFU1")
#Import data sample
mapping_file= import_qiime_sample_data("~/Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/Mapping_EPFU_corrected_format.txt")
#Create phyloseq object with Halomonas and Shewanella Filtered
EPFU <- phyloseq(otu_table(seqtabnochim5, taxa_are_rows=FALSE), sample_data(mapping_file),
                 tax_table(taxa5), phy_tree(tree))

#Data exploration
sample_names(EPFU)
ntaxa(EPFU)
nsamples(EPFU)
rank_names(EPFU)
#Sequence number
FF=sample_sums(EPFU)
min(FF)
max(FF)
mean(FF)
FF

#Extract Mock for analysis
Mockphylo=subset_samples(EPFU, sampleID == "Mock")
ntaxa(Mockphylo)
get_taxa_unique(Mockphylo, "Genus")
relMock <- transform_sample_counts(Mockphylo, function(OTU) OTU/sum(OTU))
Moclrelmore=filter_taxa(relMock, function(x) mean(x) > 1e-3, TRUE)
TopMock200 = names(sort(taxa_sums(Mockphylo), TRUE)[1:200])
Mock200 = prune_taxa(TopMock200, Mockphylo)
plot_bar(Moclrelmore, "Genus")


#Prune not included samples in Post or Pre analysis
pruneEpfu <- prune_samples(sample_names(EPFU) != "RLBat2", EPFU) # Remove 
pruneEpfu <- prune_samples(sample_names(pruneEpfu) != "RLBat6", pruneEpfu) # Remove 
pruneEpfu <- prune_samples(sample_names(pruneEpfu) != "Mock", pruneEpfu) # Remove 
pruneEpfu <- prune_samples(sample_names(pruneEpfu) != "RLWall1", pruneEpfu) # Remove 
pruneEpfu <- prune_samples(sample_names(pruneEpfu) != "RLBat5", pruneEpfu) # Remove 
pruneEpfu <- prune_samples(sample_names(pruneEpfu) != "RLBat7", pruneEpfu) # Remove 
pruneEpfu <- prune_samples(sample_names(pruneEpfu) != "RLBatIE1", pruneEpfu) # Remove 
pruneEpfu <- prune_samples(sample_names(pruneEpfu) != "RLBatIE17", pruneEpfu) # Remove 
pruneEpfu <- prune_samples(sample_names(pruneEpfu) != "RLBatIE18", pruneEpfu) # Remove
pruneEpfu <- prune_samples(sample_names(pruneEpfu) != "RLBatIE2", pruneEpfu) # Remove


#Filter taxa less abundant than 10 counts
pruneEpfufilter = filter_taxa(pruneEpfu, function(x) max(x) > 10, TRUE)


#Plot more abundant Genus
top20 <- names(sort(taxa_sums(pruneEpfufilter), decreasing=TRUE)[1:200])
ps.top20 <- transform_sample_counts(pruneEpfufilter, function(OTU) OTU/sum(OTU))
ps.top20 <- prune_taxa(top20, ps.top20)
plot_bar(ps.top20, x = "sampleID", fill="Genus") 


#Total Sequences
pruneEpfufilter
tt=sample_sums(pruneEpfufilter)
min(tt)
max(tt)
mean(tt)
tt


#Keep samples with more than 11000 sequences
Epfuphys = prune_samples(sample_sums(pruneEpfufilter)>11000, pruneEpfufilter)
sample_names(Epfuphys)


#Plot more abundant samples
topEpfuphys <- names(sort(taxa_sums(Epfuphys), decreasing=TRUE)[1:100])
ps.topEpfuphys <- transform_sample_counts(Epfuphys, function(OTU) OTU/sum(OTU))
ps.topEpfuphys <- prune_taxa(topEpfuphys, ps.topEpfuphys)
plot_bar(ps.topEpfuphys, x = "sampleID", fill="Genus") 


# Extract Control10 for analysis
Controlpostcage10phylo=subset_samples(EPFU, sampleID == "Controlpostcage10")
ntaxa(Controlpostcage10phylo)
get_taxa_unique(Controlpostcage10phylo, "Genus")
TopControlpostcage10phylo = names(sort(taxa_sums(Controlpostcage10phylo), TRUE)[1:100])
relcont10 <- transform_sample_counts(Controlpostcage10phylo, function(OTU) OTU/sum(OTU))
prunerelcont10 <- prune_taxa(TopControlpostcage10phylo, relcont10)
plot_bar(prunerelcont10, "Genus")
#Totally different relative composition of major bacteria for control10





###########################
#### Transport efffect ####
###########################

#Filter taxa less abundant than 10 counts
Epfutransp = filter_taxa(EPFU, function(x) max(x) > 10, TRUE)
#Keep samples with more than 11000 sequences
Epfutranspphys = prune_samples(sample_sums(Epfutransp)>11000, Epfutransp)
Epfu_prelab_cave=subset_samples(Epfutranspphys, Prelabcave == "Yes")
sample_names(Epfu_prelab_cave)
#Rarefy at even depth
Rare_Epfu_prelab_cave=rarefy_even_depth(Epfu_prelab_cave, rngseed=102)
#Check rarefying
sample_sums(Rare_Epfu_prelab_cave)[1:10] #34486 seqs


####Beta diversity Tranport####
#Calculate UniFrac weigthed (WUF) and unweigthed (UF) and check if euclidian distance
library("ade4")
DistWUFtransp =distance(Rare_Epfu_prelab_cave, method = "wuniFrac")
is.euclid(DistWUFtransp)
is.euclid(sqrt(DistWUFtransp))
DistUFtransp = distance(Rare_Epfu_prelab_cave, method = "UniFrac")
DistWUFtransp =distance(Rare_Epfu_prelab_cave, method = "wuniFrac")
is.euclid(DistUFtransp)

#Ordination PCoA
ordWUFtransp = ordinate(Rare_Epfu_prelab_cave, method = "PCoA", distance = sqrt(DistWUFtransp))
ordUFtransp = ordinate(Rare_Epfu_prelab_cave, method = "PCoA", distance = DistUFtransp)

#Plot Ordination WUF
PlotWUFtransp= plot_ordination(Rare_Epfu_prelab_cave, ordWUFtransp, shape = "Laborcave") + ggtitle("B \n")
PlotWUFtransp=PlotWUFtransp + theme(plot.subtitle = element_text(vjust = 1), 
                                      plot.caption = element_text(vjust = 1), 
                                      panel.grid.major = element_line(colour = "gray88"), 
                                      panel.grid.minor = element_line(colour = "gray88"), 
                                      axis.title = element_text(size = 10), 
                                      axis.text = element_text(size = 9), 
                                      legend.text = element_text(size = 11), 
                                      legend.title = element_text(size = 12, 
                                                                  face = "bold"), panel.background = element_rect(fill = NA), 
                                      plot.background = element_rect(colour = NA), 
                                      legend.key = element_rect(fill = NA, 
                                                                size = 1), legend.background = element_rect(fill = NA)) +labs(shape="bats sampling location")
PlotWUFtransp
PlotWUFtransp=PlotWUFtransp+theme(legend.position = "none")


#Plot Ordination UF
PlotUFtransp= plot_ordination(Rare_Epfu_prelab_cave, ordUFPrePost, shape="Laborcave") + ggtitle("A \n")
PlotUFtransp=PlotUFtransp + theme(plot.subtitle = element_text(vjust = 1), 
                                    plot.caption = element_text(vjust = 1), 
                                    panel.grid.major = element_line(colour = "gray88"), 
                                    panel.grid.minor = element_line(colour = "gray88"), 
                                    axis.title = element_text(size = 10), 
                                    axis.text = element_text(size = 9), 
                                    legend.text = element_text(size = 11), 
                                    legend.title = element_text(size = 12, 
                                                                face = "bold"), panel.background = element_rect(fill = NA), 
                                    plot.background = element_rect(colour = NA), 
                                    legend.key = element_rect(fill = NA, 
                                                              size = 1), legend.background = element_rect(fill = NA))  
PlotUFtransp2=PlotUFtransp+theme(legend.position = "none") 

#2 panels figure
library("Rmisc")
multiplot(PlotUFtransp2, PlotWUFtransp, cols=1)


####Betadisper transport####
#betadisper UF transp
betadisperUFtransp=betadisper(DistUFtransp,data.frame(sample_data(Rare_Epfu_prelab_cave))$Laborcave)
permutebetadisperUFtransp=permutest(betadisperUFtransp, permutations = 9999)
permutebetadisperUFtransp$tab # Not homogene
plot(betadisperUFtransp)
#betadisper WUF transp
betadisperWUFtransp=betadisper(DistWUFtransp,data.frame(sample_data(Rare_Epfu_prelab_cave))$Laborcave)
permutebetadisperWUFtransp=permutest(betadisperWUFtransp, permutations = 9999)
permutebetadisperWUFtransp$tab # Not homogene!
plot(betadisperWUFtransp)


####DbRDA transport####
#Import explanatory table transport
Matrix_transp=read.table("~/Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/DbRDA_transp.txt")
Matrix_transp=as.data.frame(Matrix_transp)
#dbRDA UF transport
dbRDA_transp=capscale(DistUFtransp~ Laborcave+Condition(Sex), Matrix_transp)
dbRDA_transp
anova.cca(dbRDA_transp, permutations=9999) #not significant
#dbRDA WUF tranport
dbRDA_transpW=capscale(DistWUFtransp~Laborcave+Condition(Sex), Matrix_transp)
dbRDA_transpW
anova.cca(dbRDA_transpW, permutations=9999) #not significant


####Alpha diversity transport####
#Estimate Richness transport
Shannontransp=estimate_richness(Rare_Epfu_prelab_cave, measures=c("Shannon"))
write.csv(Shannontransp, "Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/alpha_div/ShannonTransportestimate.csv")
#Import table transport shannon
Shannontranspmat= read.table("~/Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/alpha_div/ShannonTransportestimate.txt", header=TRUE)
#Mean distance per group transport
aggregate(Shannontranspmat[,1], list(Shannontranspmat$Laborcave), mean)
#Check data normality
hist(Shannontranspmat$Shannon,col="coral", main="Alpha diversity", xlab="Shannon")
#Shapiro test
lmt = lm(Shannon~ Laborcave, data=Shannontranspmat)
shapiro.test(resid(lmt)) #Normal
#Nul model transport
lm0t = lm(Shannon~ 1, data=Shannontranspmat)
#Shannon Linear model transport
almt=anova(lm0t, lmt) #Not significant







##########################
#### Pre captive bats ####
##########################

#Create phyloseq object Pre captive bats only
Epfu_Pre=subset_samples(EPFU, Pre_or_Post == "Pre")
Epfu_Pre
#Filter taxa less abundant than 10 counts
Epfu_Pre = filter_taxa(Epfu_Pre, function(x) max(x) > 10, TRUE)
#Keep samples with more than 11000 sequences
Epfu_Pre = prune_samples(sample_sums(Epfu_Pre)>11000, Epfu_Pre)
#Rarefy at even depth
Epfu_Pre_rare=rarefy_even_depth(Epfu_Pre, rngseed=102)
#Check rarefying
sample_sums(Epfu_Pre_rare)[1:10] #34407



####Beta diversity Pre####
#Calculate UniFrac weigthed (WUF) and unweigthed (UF) and check if euclidian distance
library("ade4")
DistWUFPre =distance(Epfu_Pre_rare, method = "wuniFrac")
is.euclid(DistWUFPre)
is.euclid(sqrt(DistWUFPre))
DistUFPre = distance(Epfu_Pre_rare, method = "UniFrac")
is.euclid(DistUFPre)


####Betadisper Pre####
#betadisper UF Pre
betadisperUFPre=betadisper(DistUFPre,data.frame(sample_data(Epfu_Pre_rare))$Infection)
permutebetadisperUFPre=permutest(betadisperUFPre, permutations = 9999)
permutebetadisperUFPre$tab # Not homogene
plot(betadisperUFPre)
#betadisper WUF Pre
betadisperWUFPre=betadisper(DistWUFPre,data.frame(sample_data(Epfu_Pre_rare))$Infection)
permutebetadisperWUFPre=permutest(betadisperWUFPre, permutations = 9999)
permutebetadisperWUFPre$tab # Not homogene!
plot(betadisperWUFPre)


####DBRDA Pre captive bat####
#DbRDA unweighted#
#Import explanatory table 
Matrix_Pre=read.table("~/Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/Beta_Div/DbRDA_Pre.txt")
Matrix_Pre=as.data.frame(Matrix_Pre)

#dbRDA UF 
dbRDA_Pre=capscale(DistUFPre~ Inoculation+ Condition(sex), Matrix_Pre)
dbRDA_Pre
anova.cca(dbRDA_Pre, permutations=9999)#not significant

#dbRDA WUF 
dbRDA_Pre=capscale(DistWUFPre~Inoculation+ Condition(sex), Matrix_Pre)
dbRDA_Pre
anova.cca(dbRDA_Pre, permutations=9999)
RsquareAdj(dbRDA_Pre)#significant


####Alpha diversity Pre####
#Estimate Richness Pre
ShannonPre=estimate_richness(Epfu_Pre_rare, measures=c("Shannon"))
write.csv(ShannonPre, "Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/alpha_div/ShannonPreestimate.csv")
#Import table Pre shannon
ShannonPrepmat= read.table("~/Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/alpha_div/ShannonPreestimate.txt", header=TRUE)
#Mean distance per group Pre
aggregate(ShannonPrepmat[,1], list(ShannonPrepmat$Inoculation), mean)
#Check data normality
hist(ShannonPrepmat$Shannon,col="coral", main="Alpha diversity", xlab="Shannon")
#Shapiro test
lmPre = lm(Shannon~ Inoculation, data=ShannonPrepmat)
shapiro.test(resid(lmPre))#Normal
#Nul model Pre
lm0Pre = lm(Shannon~ 1, data=ShannonPrepmat)
#Shannon Linear model
alm=anova(lm0Pre, lmPre)#Not significant







###############################
#### Pre-Post captive bats ####
###############################

#Create phyloseq object Pre_Post
Epfu_Pre_Post=subset_samples(Epfuphys, Laborcave == "Lab")
Epfu_Pre_Post
sum(sample_sums(Epfu_Pre_Post))
mean(sample_sums(Epfu_Pre_Post))
min(sample_sums(Epfu_Pre_Post))
max(sample_sums(Epfu_Pre_Post))

#Rarefy at even depth Pre_Post
Epfu_Pre_Postrarefied=rarefy_even_depth(Epfu_Pre_Post, rngseed=102)
#Check rarefying
sample_sums(Epfu_Pre_Postrarefied)[1:10]#3416 seqs

####Beta Diversity Pre Post####
#Calculate UniFrac weigthed (WUF) and unweigthed (UF) and check if euclidian distance
library("ade4")
DistWUFPrePost =distance(Epfu_Pre_Postrarefied, method = "wuniFrac")
is.euclid(DistWUFPrePost)
is.euclid(sqrt(DistWUFPrePost))
DistUFPrePost = distance(Epfu_Pre_Postrarefied, method = "UniFrac")
is.euclid(DistUFPrePost)

#Create distance matrix Pre Post
matrixUFPrePost=as.matrix(DistUFPrePost)
write.csv(matrixUFPrePost, file="Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/Beta_Div/matrixUFPrePost.csv")
matrixWUFPrePost=as.matrix(DistWUFPrePost)
write.csv(matrixWUFPrePost, file="Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/Beta_Div/matrixWUFPrePost.csv")

#Ordination PCoA Pre Post
ordWUFPrePost = ordinate(Epfu_Pre_Postrarefied, method = "PCoA", distance = sqrt(DistWUFPrePost))
ordUFPrePost = ordinate(Epfu_Pre_Postrarefied, method = "PCoA", distance = DistUFPrePost)

#Plot Ordination WUF Pre Post
PlotWUFPrePost= plot_ordination(Epfu_Pre_Post, ordWUFPrePost, shape = "Pre_or_Post") + ggtitle("B \n")
PlotWUFPrePost=PlotWUFPrePost + theme(plot.subtitle = element_text(vjust = 1), 
                                      plot.caption = element_text(vjust = 1), 
                                      panel.grid.major = element_line(colour = "gray88"), 
                                      panel.grid.minor = element_line(colour = "gray88"), 
                                      axis.title = element_text(size = 10), 
                                      axis.text = element_text(size = 9), 
                                      legend.text = element_text(size = 11), 
                                      legend.title = element_text(size = 12, 
                                                                  face = "bold"), panel.background = element_rect(fill = NA), 
                                      plot.background = element_rect(colour = NA), 
                                      legend.key = element_rect(fill = NA, 
                                                                size = 1), legend.background = element_rect(fill = NA)) +labs(shape="Captivity Timepoint")
PlotWUFPrePost
PlotWUFPrePost2=PlotWUFPrePost+theme(legend.position = "none")

#Plot Ordination UF Pre Post
PlotUFPrePost= plot_ordination(Epfu_Pre_Post, ordUFPrePost, shape="Pre_or_Post") + ggtitle("A \n")
PlotUFPrePost=PlotUFPrePost + theme(plot.subtitle = element_text(vjust = 1), 
                                    plot.caption = element_text(vjust = 1), 
                                    panel.grid.major = element_line(colour = "gray88"), 
                                    panel.grid.minor = element_line(colour = "gray88"), 
                                    axis.title = element_text(size = 10), 
                                    axis.text = element_text(size = 9), 
                                    legend.text = element_text(size = 11), 
                                    legend.title = element_text(size = 12, 
                                                                face = "bold"), panel.background = element_rect(fill = NA), 
                                    plot.background = element_rect(colour = NA), 
                                    legend.key = element_rect(fill = NA, 
                                                              size = 1), legend.background = element_rect(fill = NA)) +labs(shape="Captivity Timepoint") 
PlotUFPrePost2=PlotUFPrePost+theme(legend.position = "none") 

#2 panels figure Pre Post
library("Rmisc")
multiplot(PlotUFPrePost2,PlotWUFPrePost2, cols=1)


####betadisper####
#betadisper UF Pre_or_Post
betadisperUFPre_or_Post=betadisper(DistUFPrePost,data.frame(sample_data(Epfu_Pre_Post))$Pre_or_Post)
permutebetadisperUFPre_or_Post=permutest(betadisperUFPre_or_Post, permutations = 9999)
permutebetadisperUFPre_or_Post$tab # Not homogene
plot(betadisperUFPre_or_Post)
#betadisper WUF Pre_or_Post
betadisperWUFPre_or_Post=betadisper(DistWUFPrePost,data.frame(sample_data(Epfu_Pre_Post))$Pre_or_Post)
permutebetadisperWUFPre_or_Post=permutest(betadisperWUFPre_or_Post, permutations = 9999)
permutebetadisperWUFPre_or_Post$tab # Not homogene!
plot(betadisperWUFPre_or_Post)

####Db-RDA Pre Post####
#dbRDA UF Pre Post
#Import explanatory table 
Matrix_Pre_Post=read.table("~/Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/Beta_Div/DbRDA_Pre_post_bat.txt")
Matrix_Pre_Post=as.data.frame(Matrix_Pre_Post)
#dbRDA UF Pre Post
dbRDA_Pre_Post=capscale(DistUFPrePost~ Pre_or_Post+ Condition(sex), Matrix_Pre_Post)
dbRDA_Pre_Post
anova.cca(dbRDA_Pre_Post, permutations=9999, strata=Matrix_Pre_Post$PairedT1T2)
RsquareAdj(dbRDA_Pre_Post)
#dbRDA WUF Pre Post 
dbRDA_Pre_PostW=capscale(DistWUFPrePost~Pre_or_Post+ Condition(sex), Matrix_Pre_Post)
dbRDA_Pre_PostW
anova.cca(dbRDA_Pre_PostW, permutations=9999, strata=Matrix_Pre_Post$PairedT1T2)
RsquareAdj(dbRDA_Pre_PostW)




####Distance Beta diversity Paired Inoculation Pre_Post####
library(nlme)
#Import table Pre Post paired
distancePrePost= read.table("~/Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/Beta_Div/Distance_table_paired_UF_WUF_PrePost.txt", header=TRUE)
View(distancePrePost)

#Mean distance per group Pre Post paired 
aggregate(distancePrePost[,1:2], list(distancePrePost$Inoculation), mean)
#Pd= Pd-inoculated sample and PBST = control
#Check data normality UF
hist(distancePrePost$UF_distance_Pre_Post,col="coral", main="Unweighted UniFrac", xlab="Unweighted UniFrac distance")
#Check data normality WUF
hist(distancePrePost$WUF_distance_Pre_Post,col="coral", main="Weighted UniFrac", xlab="Weighted UniFrac distance")
#Shapiro test UF Model
lm2 = lme(UF_distance_Pre_Post~ 1, random=list(~1|Cageid), data=distancePrePost, method="ML")
shapiro.test(resid(lm2)) #Normal
#Shapiro test WUF Model
lm3 = lme(WUF_distance_Pre_Post~ 1, random=list(~1|Cageid), data=distancePrePost, method="ML")
shapiro.test(resid(lm3)) #Normal
#Model Inoculation UF
lm2.1 = lme(UF_distance_Pre_Post~ Inoculation, random=list(~1|Cageid), data=distancePrePost, method="ML")
shapiro.test(resid(lm2.1))
#liklihood ratio test with a chi-sq dist Pre Post inoculation
anova(lm2, lm2.1) #Significant model!
#REML Model interpretation Pre Post inoculation
lm2.1REML = lme(UF_distance_Pre_Post~ Inoculation, random=list(~1|Cageid), data=distancePrePost, method="REML")
summary(lm2.1REML)
#Model Inoculation WUF Pre Post inoculation
lm3.1 = lme(WUF_distance_Pre_Post~ Inoculation, random=list(~1|Cageid), data=distancePrePost, method="ML")
shapiro.test(resid(lm3.1)) #Normal
#liklihood ratio test with a chi-sq dist
anova(lm3, lm3.1) #Significant model!
#REML Model interpretation Pre Post Inoculation
lm3.1REML = lme(WUF_distance_Pre_Post~ Inoculation, random=list(~1|Cageid), data=distancePrePost, method="REML")
summary(lm3.1REML)

#Create boxplot plot UF Pre Post inoculation
library(Hmisc)
plotdisUF <- ggplot(distancePrePost, aes(factor(Inoculation), UF_distance_Pre_Post)) 
plotdisUFboxplot<-plotdisUF + geom_boxplot()+ theme(plot.subtitle = element_text(vjust = 1), plot.caption = element_text(vjust = 1), axis.line = element_line(size = 0.6, linetype = "solid"), axis.ticks = element_line(colour = "gray31", linetype = "blank"), panel.grid.major = element_line(colour = "gray95"), panel.grid.minor = element_line(colour = "gray95"), axis.title = element_text(size = 11), legend.title = element_text(size = 11), panel.background = element_rect(fill = NA), legend.key = element_rect(size = 0.6)) +labs(x = "", y = "Unweighted UniFrac distance")+ stat_summary(fun.data=mean_sdl, geom="pointrange", color="black")+ labs(tag = "A") + scale_x_discrete(labels = c('Control','Pd-inoculated'))
plotdisUFboxplot=plotdisUFboxplot+geom_dotplot(binaxis='y', stackdir='center', dotsize=0.6)
#Create boxplot plot WUF Pre Post inoculation
plotdisWUF <- ggplot(distancePrePost, aes(factor(Inoculation), WUF_distance_Pre_Post))
plotdisWUFboxplot<-plotdisWUF + geom_boxplot() + theme(plot.subtitle = element_text(vjust = 1), plot.caption = element_text(vjust = 1), axis.line = element_line(size = 0.6, linetype = "solid"), axis.ticks = element_line(colour = "gray31", linetype = "blank"), panel.grid.major = element_line(colour = "gray95"), panel.grid.minor = element_line(colour = "gray95"), axis.title = element_text(size = 11), legend.title = element_text(size = 11), panel.background = element_rect(fill = NA), legend.key = element_rect(size = 0.6)) +labs(x = "", y = "Weighted UniFrac distance")+ stat_summary(fun.data=mean_sdl, geom="pointrange", color="black") + labs(tag = "B") + scale_x_discrete(labels = c('Control','Pd-inoculated'))
plotdisWUFboxplot=plotdisWUFboxplot +geom_dotplot(binaxis='y', stackdir='center', dotsize=0.6)
#2 panels figure
library("Rmisc")
multiplot(plotdisUFboxplot, plotdisWUFboxplot, cols=2)
par(mfrow=c(2,1))


#####Alpha Diversity Pre Post####
#Estimate Richness
ShannonPrePost=estimate_richness(Epfu_Pre_Post, measures=c("Shannon"))
write.csv(ShannonPrePost, "Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/alpha_div/ShannonPrePostestimate.csv")
#Import table Pre Post alpha
ShannonPrePost= read.table("~/Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/alpha_div/Shannon_Pre_Post.txt", header=TRUE)
#Mean distance per group Pre Post
aggregate(ShannonPrePost[,1], list(ShannonPrePost$Post_Pre), mean)
ShannonPrePost$Post_Pre
#Check data normality
hist(ShannonPrePost$Shannon,col="coral", main="Alpha diversity", xlab="Shannon")
#Shapiro test
lm1.1 = lm(Shannon~ Post_Pre, data=ShannonPrePost)
shapiro.test(resid(lm1.1))#Normal
#Nul model 
lm0 = lm(Shannon~ 1, data=ShannonPrePost)
#Shannon Linear model
alm11=anova(lm0, lm1.1)#Significant
#Model interpretation lm1.1 Pre Post
summary(lm1.1)

####Difference Alpha diversity Pre post paired Inoculation####
#Import table
AlphadiffPrePost= read.table("~/Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/alpha_div/alpha_difference_Pre_Post_Paired.txt", header=TRUE)
View(AlphadiffPrePost)
#Check data normality of Alpha paired difference
hist(AlphadiffPrePost$Difference_shannon,col="coral", main="Shannon difference", xlab="Shannon")
#Shapiro test alpha difference #Nul model
lm4 = lm(Difference_shannon~ 1, data=AlphadiffPrePost)
#Shannon Linear model
lm4.1 = lm(Difference_shannon~ Inoculation, data=AlphadiffPrePost)
shapiro.test(resid(lm4.1)) #Normal
#Model Test Pre post paired Inoculation
anova(lm4, lm4.1) #Not significant model







#################################
###### Post captivity only ######
#################################

#Create phyloseq object Post_only 
Epfu_Post_only=subset_samples(Epfuphys, Pre_or_Post == "Post")

#Rarefy at even depth
Epfu_Post_onlyrarefied=rarefy_even_depth(Epfu_Post_only, rngseed=102)
#Checking rarefying
sample_sums(Epfu_Post_onlyrarefied)[1:10]
#39482 seqs
Epfu_Post_only=Epfu_Post_onlyrarefied    

####Beta diversity Post####
DistWUFPost_only = distance(Epfu_Post_only, method = "wUniFrac")
DistUFPost_only = distance(Epfu_Post_only, method = "UniFrac")

####Betadisper Post####
#betadisper UF Inoculation
betadisperUFPost_only_Inoculation=betadisper(DistUFPost_only, data.frame(sample_data(Epfu_Post_only))$Infection)
permutebetadisperUFPost_only_Inoculation=permutest(betadisperUFPost_only_Inoculation, permutations = 9999)
permutebetadisperUFPost_only_Inoculation$tab # Homogene
plot(betadisperUFPost_only_Inoculation)
#betadisper WUF Inoculation
betadisperWUFPost_only_Inoculation=betadisper(DistWUFPost_only,data.frame(sample_data(Epfu_Post_only))$Infection)
permutebetadisperWUFPost_only_Inoculation=permutest(betadisperWUFPost_only_Inoculation, permutations = 9999)
permutebetadisperWUFPost_only_Inoculation$tab #homogene!
plot(betadisperWUFPost_only_Inoculation)


####DbRDA Post####
#Import explanatory table Post
Matrix_Post=read.table("~/Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/Beta_Div/Post_Only_dbRDA.txt")
Matrix_Post=as.data.frame(Matrix_Post)
Matrix_Post$Cageid=as.factor(Matrix_Post$Cageid)
#dbRDA UF Post
dbRDA_Post=capscale(DistUFPost_only~Inoculation+Condition(Sex+Incubator+Cageid), Matrix_Post)
dbRDA_Post
anova.cca(dbRDA_Post, permutations=9999)
RsquareAdj(dbRDA_Post)
#dbRDA WUF Post
dbRDA_PostW=capscale(DistWUFPost_only~Inoculation+Condition(Sex+Incubator+Cageid), Matrix_Post)
dbRDA_PostW
anova.cca(dbRDA_PostW, permutations=9999)
RsquareAdj(dbRDA_PostW)

#dbRDA UF Cage Post
dbRDA_PostC=capscale(DistUFPost_only~Cageid+Condition(Sex+Incubator+Inoculation), Matrix_Post)
dbRDA_PostC
anova.cca(dbRDA_PostC, permutations=9999)
RsquareAdj(dbRDA_PostC)
#dbRDA WUF Cage Post
dbRDA_PostWC=capscale(DistWUFPost_only~Cageid+Condition(Sex+Incubator+Inoculation), Matrix_Post)
dbRDA_PostWC
anova.cca(dbRDA_PostWC, permutations=9999)
RsquareAdj(dbRDA_PostWC)


####Post captivity model test####
#Import table Post
ShannonPost= read.table("~/Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/alpha_div/Shannon_Post.txt", header=TRUE)
#Mean distance per group Post
aggregate(ShannonPost[,1], list(ShannonPost$Inoculation), mean)
#Check data normality
hist(ShannonPost$Shannon,col="coral", main="Alpha diversity", xlab="Shannon")
#Shapiro test Post
lm22 = lme(Shannon~ Inoculation, random=list(~1|Cage), data=ShannonPost, method = "ML")
shapiro.test(resid(lm22))#Normal, p-value =0.74
#Nul model Post
lm20 = lme(Shannon~ 1, random=list(~1|Cage), data=ShannonPost, method = "ML")
#Shannon Linear mixed model #liklihood ratio test with a chi-sq dist Post
anova(lm20, lm22)#Not significant






########################################################
#### Analysis of Composition of Microbiomes (ANCOM) ####
########################################################
set.seed(3)
source("Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/Ancom/ANCOM_updated_code.R")

#Create taxa table
#Merge same Genus and sum up abundance 
# Author Nicolas Fortin St-Gelais
# where m=community matrix (cols = taxa, rows = sites)
# c= a vertor with the selected taxonomic level for agregation and OTU as name
# colnames(m) and names(c) must be identical and unique
mergeByCat<- function(m,c){
  c=c[!is.na(c)]
  c=c[names(c)%in%colnames(m)]
  m=m[,names(c)]
  mergedM=matrix(NA,nrow(m),length(unique(c)),dimnames=list(rownames(m),unique(c)))
  for(i in unique(c)){
    mergedM[,i]=rowSums(m[,c%in%as.character(i),drop=F])}
  return(mergedM)
}
taxa6=cbind(paste0("asv",seq(1,dim(taxa5)[1],1)),taxa5)

m=seqtabnochim5
colnames(m)=taxa6[,1]
c.genus=taxa6[,7]
names(c.genus)=taxa6[,1]

#Create taxa table merge by genus
Genustable=mergeByCat(m,c.genus)
View(Genustable)

####Ancom Pre-Post####
#Create Taxa table Pre Post only
GenustablePrePost=(Genustable[5:50,])
#Retrieve zero taxa
GenustablePrePost1=GenustablePrePost[, colSums(GenustablePrePost) != 0] 
#Export Matrix to modify
write.csv(GenustablePrePost1,"Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/Ancom/GenustablePrePost1")
write.csv(Matrix_Pre_Post,"Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/Ancom/Matrix_PrePost")
#Import Modified Matrix
Matrix_Pre_Post_Ancom=read.table("Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/Ancom/Matrix_PrePost2.txt", header=TRUE)

#Ancom Pre_Post Genus only >0.1%
GenustablePrePost3=read.table("Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/Ancom/GenustablePrePost30.001.txt", header=TRUE)
Pre_PostAncom001=ANCOM.main(OTUdat=GenustablePrePost3, Vardat=Matrix_Pre_Post_Ancom, adjusted=FALSE, repeated=T, main.var="Pre_or_Post", adj.formula=NULL, repeat.var="PairedT1T2", longitudinal = F, multcorr=2, sig=0.05, prev.cut=0.9)
#See results
Pre_PostAncom001$W.taxa

#Identify genera more than 0.1% by plot
relPrePost <- transform_sample_counts(Epfu_Pre_Post, function(OTU) OTU/sum(OTU))
Epfu_Pre_Post0.01=filter_taxa(relPrePost, function(x) mean(x) > 1e-3, TRUE)
plot=plot_bar(Epfu_Pre_Post0.01, x="sampleID", fill="Genus")
plot2=plot +xlab(NULL)
#Define the number of colors you want
nb.cols <- 14
mycolors <- colorRampPalette(brewer.pal(14, "Paired"))(nb.cols)
#Plot
plot3=plot2+theme(plot.subtitle = element_text(vjust = 1), 
                  plot.caption = element_text(vjust = 1), 
                  panel.grid.major = element_line(colour = "gray88"), 
                  axis.title = element_text(size = 10), 
                  axis.text = element_text(size = 9), 
                  legend.text = element_text(size = 11), 
                  legend.title = element_text(size = 12, 
                                              face = "bold"), panel.background = element_rect(fill = NA))

Plot4=plot3+geom_bar(aes(color=Genus, fill=Genus), stat="identity", position="stack")
Plot4+scale_fill_manual(values = mycolors)


#Create Barchart Pre Post most abundant feature in relative abundance
library(reshape2)
df_long <- melt(GenustablePrePost3, id.vars = "Sample.ID", variable.name = "Genus")
plotbar=ggplot(df_long, aes(x = Sample.ID, y = value, fill = Genus)) + 
  geom_bar(position="fill", stat = "identity") + ylab("Relative abundance") +xlab(NULL)
plotbar=plotbar+theme(axis.text.x = element_text(angle = 90, hjust = 1))


Plotbarfinal=plotbar+theme(plot.subtitle = element_text(vjust = 1), 
                           plot.caption = element_text(vjust = 1), 
                           panel.grid.major = element_line(colour = "gray88"), 
                           axis.title = element_text(size = 10), 
                           axis.text = element_text(size = 9), 
                           legend.text = element_text(size = 11), 
                           legend.title = element_text(size = 12, 
                                                       face = "bold"), panel.background = element_rect(fill = NA))

Plotbarfinal+scale_fill_manual(values = mycolors)




####Ancom Post####

#Identify genera more than 0.1%
relPost <- transform_sample_counts(Epfu_Post_only, function(OTU) OTU/sum(OTU))
Epfu_relPost=filter_taxa(relPost, function(x) mean(x) > 1e-3, TRUE)
plot33=plot_bar(Epfu_relPost, x="sampleID", fill="Genus")
plot22=plot33 +xlab(NULL)
#Import Modified Matrix
GenustablePost=read.table("Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/Ancom/GenustablePost3.txt", header=TRUE)
Matrix_Post_Ancom=read.table("Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/Ancom/Matrix_Post_Ancom.txt", header=TRUE)

#Ancom Post
PostAncom=ANCOM.main(OTUdat=GenustablePost, Vardat=Matrix_Post_Ancom, adjusted=TRUE, repeated=F, main.var="Inoculation", adj.formula="Cageid+Incubator", repeat.var=NULL, longitudinal = F, multcorr=2, sig=0.05, prev.cut=0.9)
#See results Post Ancom
PostAncom$W.taxa





#########################
#### Weigth analysis ####
#########################

#Import weight table
Fit=read.table("~/Desktop/EPFU_FG_AUDE_2017/7.DADA2_EPFU/Fitness/IE2017_weights_EPFU.txt", header = TRUE)
#Check data normality
hist(Fit$mass.diff.proportion,col="coral", main="mass.diff.proportion", xlab="Proportion")
#Nul model
lmfit0 = lm(mass.diff.proportion~ 1, data=Fit)
#Shannon Linear model 
lmfit1 = lm(mass.diff.proportion~ infection, data=Fit)
shapiro.test(resid(lmfit1))#Normal
#Model test
anova(lmfit0, lmfit1)#Not significant

#Boxplot infection proportion difference 
library(Hmisc)
plotfit <- ggplot(Fit, aes(factor(infection), mass.diff.proportion)) 
plotFit1<-plotfit + geom_boxplot()+ theme(plot.subtitle = element_text(vjust = 1), plot.caption = element_text(vjust = 1), axis.line = element_line(size = 0.6, linetype = "solid"), axis.ticks = element_line(colour = "gray31", linetype = "blank"), panel.grid.major = element_line(colour = "gray95"), panel.grid.minor = element_line(colour = "gray95"), axis.title = element_text(size = 11), legend.title = element_text(size = 11), panel.background = element_rect(fill = NA), legend.key = element_rect(size = 0.6)) +labs(x = "", y = "Proportion difference")+ stat_summary(fun.data=mean_sdl, geom="pointrange", color="black")+ scale_x_discrete(labels = c('Control','Pd-inoculated'))
plotFit1=plotFit1+geom_dotplot(binaxis='y', stackdir='center', dotsize=0.6)


#Difference in weight at experiment start
#Nul model
lmfit0start = lm(mass.start~ 1, data=Fit)
#Shannon Linear model
lmfit1start = lm(mass.start~ infection, data=Fit)
shapiro.test(resid(lmfit1start))#Normal
#Model test
anova(lmfit0start, lmfit1start)#Not significant


#Difference in weight at experiment end
#Nul model
lmfit0end = lm(mass.end~ 1, data=Fit)
#Shannon Linear mixed model #liklihood ratio test with a chi-sq dist
lmfit1end = lm(mass.end~ infection, data=Fit)
shapiro.test(resid(lmfit1end))#Normal
#Model Test
anova(lmfit0end, lmfit1end)#Not significant


#Weight according to sex at experiment start
#Nul model
lmfit0startsex = lm(mass.start~ 1, data=Fit)
#Shannon Linear model 
lmfit1startsex = lm(mass.start~ sex, data=Fit)
shapiro.test(resid(lmfit1startsex))#Normal
#Model test
anova(lmfit0startsex, lmfit1startsex)#significant


#Weight according to sex at experiment end
#Nul model
lmfit0endsex = lm(mass.end~ 1, data=Fit)
#Shannon Linear model
lmfit1endsex = lm(mass.end~ sex, data=Fit)
shapiro.test(resid(lmfit1endsex))#Normal
#Model Test
anova(lmfit0endsex, lmfit1endsex)#significant
summary(lmfit1endsex)


#Weight lost proportion by sex
#Nul model
lmfit0sex = lm(sqrt(mass.diff.proportion)~ 1, data=Fit)
#Shannon Linear model
lmfit1sex = lm(sqrt(mass.diff.proportion)~ sex, data=Fit)
shapiro.test(resid(lmfit1sex))#Normal
#Model Test
anova(lmfit0sex, lmfit1sex)#Not significant
